@@ -1,8 +1,11 @@
 use cached::proc_macro::cached;
 use jmespatch::{Context, ErrorReason, JmespathError, Rcvar, Variable};
+use jmespatch::ast::Ast;
 use jmespatch::functions::{ArgumentType, Function, Signature};
 use regex::{Match, Regex};
 
+const ERROR_MSG: &str = "Regex must be a literal string please only use &'...'";
+
 pub struct RegexFn {
     signature: Signature,
 }
@@ -18,8 +21,8 @@ impl RegexFn {
         RegexFn {
             signature: Signature::new(
                 vec![
-                    ArgumentType::String,
-                    ArgumentType::Union(vec![ArgumentType::String, ArgumentType::Null])
+                    ArgumentType::Any,
+                    ArgumentType::Any,
                 ],
                 None,
             )
@@ -46,33 +49,38 @@ impl RegexFn {
             Variable::Array(matches)
         }).unwrap_or(Variable::Null)
     }
+
+    fn string_literal<'s>(var: &'s Rcvar, ctx: &Context<'_>) -> Result<&'s str, JmespathError> {
+        return match var.as_expref() {
+            Some(Ast::Literal { ref value, .. }) => {
+                match value.as_string() {
+                    Some(str) => Ok(str.as_str()),
+                    _ => Err(JmespathError::from_ctx(
+                        ctx,
+                        ErrorReason::Parse(ERROR_MSG.to_owned()),
+                    ))
+                }
+            }
+            _ => {
+                Err(JmespathError::from_ctx(
+                    ctx,
+                    ErrorReason::Parse(ERROR_MSG.to_owned()),
+                ))
+            }
+        };
+    }
 }
 
 impl Function for RegexFn {
     fn evaluate(&self, args: &[Rcvar], ctx: &mut Context<'_>) -> Result<Rcvar, JmespathError> {
         self.signature.validate(args, ctx)?;
-        if args[1].is_null() {
-            return Ok(Rcvar::new(Variable::Null));
-        }
+        let re_str = Self::string_literal(&args[0], ctx)?;
+        let regex = compile_regex(re_str.to_owned())?;
 
-        let regex_str = args[0].as_string().ok_or_else(|| {
-            JmespathError::new(
-                "",
-                0,
-                ErrorReason::Parse("Expression argument should be a string".to_owned()),
-            )
-        })?;
-
-        let regex = compile_regex(regex_str.to_owned())?;
-        let payload = args[1].as_string().ok_or_else(|| {
-            JmespathError::new(
-                "",
-                0,
-                ErrorReason::Parse("Payload must be a string".to_owned()),
-            )
-        })?;
-
-        Ok(Rcvar::new(Self::match_regex(regex, payload)))
+        return match args[1].as_string() {
+            Some(payload) => Ok(Rcvar::new(Self::match_regex(regex, payload))),
+            None => Ok(Rcvar::new(Variable::Null))
+        };
     }
 }
 
@@ -90,13 +98,15 @@ fn compile_regex(regex_str: String) -> Result<Regex, JmespathError> {
 
 #[cfg(test)]
 mod regex_tests {
+    use jmespatch::{ErrorReason, JmespathError};
     use serde_json::json;
 
+    use crate::exp_engine::regex_fn::ERROR_MSG;
     use crate::exp_engine::runtime::compile_expr;
 
     #[test]
     fn test_match_returns_matched_segments_in_regex() {
-        let exp = compile_expr("match('foo', a.b)".to_string()).unwrap();
+        let exp = compile_expr("match(&'foo', a.b)".to_string()).unwrap();
         let r = exp.search(json!({
             "a": {
                 "b": "food"
@@ -111,7 +121,7 @@ mod regex_tests {
 
     #[test]
     fn test_match_returns_null_unmatched_segments_in_regex() {
-        let exp = compile_expr("match('foo', a.b)".to_string()).unwrap();
+        let exp = compile_expr("match(&'foo', a.b)".to_string()).unwrap();
         let r = exp.search(json!({
             "a": {
                 "b": "bar"
@@ -123,7 +133,7 @@ mod regex_tests {
 
     #[test]
     fn test_match_returns_null_when_element_is_null() {
-        let exp = compile_expr("match('foo', a.c)".to_string()).unwrap();
+        let exp = compile_expr("match(&'foo', a.c)".to_string()).unwrap();
         let r = exp.search(json!({
             "a": {
                 "b": "bar"
@@ -135,7 +145,7 @@ mod regex_tests {
 
     #[test]
     fn test_match_returns_multiple_segments() {
-        let exp = compile_expr(r"match('(\d{4})-(\d{2})-(\d{2})', a)".to_string()).unwrap();
+        let exp = compile_expr(r"match(&'(\d{4})-(\d{2})-(\d{2})', a)".to_string()).unwrap();
         let r = exp.search(json!({
             "a": "2010-03-14"
         })).unwrap();
@@ -147,4 +157,40 @@ mod regex_tests {
         assert_eq!(matches[2].as_string().unwrap(), "03");
         assert_eq!(matches[3].as_string().unwrap(), "14");
     }
+
+    #[test]
+    fn test_match_wont_compile_non_literal_regex() {
+        let exp = compile_expr(r"match(a, a)".to_string()).unwrap();
+        let r = exp.search(json!({
+            "a": "2010-03-14"
+        }));
+
+        match r.err() {
+            Some(
+                JmespathError {
+                    reason: ErrorReason::Parse(ref reason),
+                    ..
+                }
+            ) => assert_eq!(reason, ERROR_MSG),
+            _ => assert!(false),
+        };
+    }
+
+    #[test]
+    fn test_match_wont_compile_non_ref_literal_regex() {
+        let exp = compile_expr(r"match('a', a)".to_string()).unwrap();
+        let r = exp.search(json!({
+            "a": "2010-03-14"
+        }));
+
+        match r.err() {
+            Some(
+                JmespathError {
+                    reason: ErrorReason::Parse(ref reason),
+                    ..
+                }
+            ) => assert_eq!(reason, ERROR_MSG),
+            _ => assert!(false),
+        };
+    }
 }
\ No newline at end of file
