@@ -1,6 +1,7 @@
 use cached::proc_macro::cached;
 use jmespatch::{Expression, JmespathError, Runtime};
 use lazy_static::lazy_static;
+use crate::exp_engine::email_fn::EmailFn;
 
 use super::regex_fn::RegexFn;
 
@@ -9,6 +10,7 @@ lazy_static! {
         let mut runtime = Runtime::new();
         runtime.register_builtin_functions();
         runtime.register_function("match", Box::new(RegexFn::new()));
+        runtime.register_function("valid_email", Box::new(EmailFn::new()));
         runtime
     };
 }
